==> haskell-git-lfs-1.2.5-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-git-lfs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 git-lfs
version:              1.2.5
visibility:           public
id:                   git-lfs-1.2.5-AJwn3kiLnVu2YRxDdnFSiI
key:                  git-lfs-1.2.5-AJwn3kiLnVu2YRxDdnFSiI
license:              AGPL-3.0-only
copyright:            2019 Joey Hess
maintainer:           Joey Hess <id@joeyh.name>
author:               Joey Hess
stability:            Stable
synopsis:             git-lfs protocol
description:          An implementation of the git-lfs protocol.
category:             Network
abi:                  1b1c7cfdcc1b107106dee57a9185ee48
exposed:              True
exposed-modules:      Network.GitLFS
import-dirs:          /usr/lib/ghc-9.4.8/site-local/git-lfs-1.2.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/git-lfs-1.2.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/git-lfs-1.2.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-git-lfs
hs-libraries:         HSgit-lfs-1.2.5-AJwn3kiLnVu2YRxDdnFSiI
depends:
    aeson-2.1.2.1-6jLf9XnWqJCFwZgyNgcXK5 base-4.17.2.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-7gqgHDj4ifWAUMF7u0wWwn
    containers-0.6.7 http-client-0.7.18-5BYajw3HNj1oXnoQDXsjn
    http-types-0.12.4-5kSnAXEr074KLJnh9ObNlR
    network-uri-2.6.4.2-Ezz3DgCiNVkB3lRSna1Fn6 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-git-lfs/html/git-lfs.haddock
haddock-html:         /usr/share/doc/haskell-git-lfs/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-git-lfs-1.2.5-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-git-lfs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 git-lfs
version:              1.2.5
visibility:           public
id:                   git-lfs-1.2.5-FOhrrrYKDHgGuDLsLyhZQH
key:                  git-lfs-1.2.5-FOhrrrYKDHgGuDLsLyhZQH
license:              AGPL-3.0-only
copyright:            2019 Joey Hess
maintainer:           Joey Hess <id@joeyh.name>
author:               Joey Hess
stability:            Stable
synopsis:             git-lfs protocol
description:          An implementation of the git-lfs protocol.
category:             Network
abi:                  1f97e174ac3177c1db31348fc082ed81
exposed:              True
exposed-modules:      Network.GitLFS
import-dirs:          /usr/lib/ghc-9.4.8/site-local/git-lfs-1.2.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/git-lfs-1.2.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/git-lfs-1.2.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-git-lfs
hs-libraries:         HSgit-lfs-1.2.5-FOhrrrYKDHgGuDLsLyhZQH
depends:
    aeson-2.1.2.1-5gViDrHjeNhDfT19MwgeMT base-4.17.2.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-D4Bx6jK2099tFJcppXDxv
    containers-0.6.7 http-client-0.7.18-F2vUdc4GuQE1q0cHPJLrjL
    http-types-0.12.4-845zQBf8K2R8QZqh3scBqV
    network-uri-2.6.4.2-9MIvjX5zY25ED43FJsYIB3 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-git-lfs/html/git-lfs.haddock
haddock-html:         /usr/share/doc/haskell-git-lfs/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
